# UQ-PhysiCell

<p align="center">
  <img src="https://raw.githubusercontent.com/heberlr/UQ_PhysiCell/development/uq_physicell/doc/icon.png" alt="pyABC logo" width="50%">
</p>

[![Run Unit Tests](https://github.com/heberlr/UQ_PhysiCell/actions/workflows/test-examples.yml/badge.svg)](https://github.com/heberlr/UQ_PhysiCell/actions/workflows/test-examples.yml)
[![Documentation Status](https://readthedocs.org/projects/uq-physicell/badge/?version=latest)](https://uq-physicell.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://badge.fury.io/py/uq-physicell.svg?updated=20241106)](https://badge.fury.io/py/uq-physicell)
[![Python](https://img.shields.io/badge/Python-%3E%3D3.10-blue?logo=python&logoColor=green)](https://python.org)

UQ-PhysiCell is a comprehensive framework for performing uncertainty quantification and parameter calibration of PhysiCell models. It provides sophisticated tools for model analysis, calibration, and model selection.

## Resources
- 📖 **Documentation**: [https://uq-physicell.readthedocs.io/en/latest/index.html](https://uq-physicell.readthedocs.io/en/latest/index.html)
- 💡 **Examples**: [https://uq-physicell.readthedocs.io/en/latest/examples.html](https://uq-physicell.readthedocs.io/en/latest/examples.html)
- 🐛 **Bug Reports**: [https://github.com/heberlr/UQ_PhysiCell/issues](https://github.com/heberlr/UQ_PhysiCell/issues)
- 💻 **Source Code**: [https://github.com/heberlr/UQ_PhysiCell](https://github.com/heberlr/UQ_PhysiCell)
<!-- - 📄 **Cite**: [...](...) -->
